@@ -8,7 +8,7 @@ void bitarray_clearsetn (unsigned char *s, size_t a, size_t b, int h)
   b += a ;
   if ((a >> 3) == ((b-1) >> 3))
   {
-    unsigned char mask = (1 << (a & 7)) - 1 ^ (1 << 1 + (b-1 & 7)) - 1 ;
+    unsigned char mask = (1 << (a & 7)) - 1 ^ (1 << (1 + (b-1 & 7))) - 1 ;
     if (h) s[a>>3] |= mask ; else s[a>>3] &= ~mask ;
   }
   else
