@@ -6,9 +6,10 @@
 
 int utc_from_tai (uint64_t *u, tai_t const *t)
 {
+  int r = 1 ;
   uint64_t tt = t->x - 10 ;
   if (t->x < 10U) return (errno = EINVAL, 0) ;
-  leapsecs_sub(&tt) ;
+  r += leapsecs_sub(&tt) ;
   *u = tt ;
-  return 1 ;
+  return r ;
 }
