@@ -12,6 +12,9 @@
 #ifndef _BSD_SOURCE
 #define _BSD_SOURCE
 #endif
+#ifndef _DEFAULT_SOURCE
+#define _DEFAULT_SOURCE
+#endif
 #ifndef _NETBSD_SOURCE
 #define _NETBSD_SOURCE
 #endif
